==> sal-display-2.22.0-20170422.013845-67-sources.jar: com/baijia/tianxiao/sal/display/dto/response/crm/DefaultClueField.java <==
package com.baijia.tianxiao.sal.display.dto.response.crm;

import com.baijia.tianxiao.sal.display.dto.annotation.FieldProp;
import lombok.Data;

import java.util.Date;

/**
 * 线索系统字段默认属性
 * Created by wangsixia on 2016/11/11.
 */
@Data
public class DefaultClueField{

    @FieldProp(name = "id", showName = "id", showStatus = 2)
    private Long id;

    @FieldProp(name = "name", showName = "姓名", showStatus = 0, queryProp = "name", lock = true, sort = true)
    private String name;

    @FieldProp(name = "mobile", showName = "手机号", showStatus = 0, queryProp = "mobile", lock = true, sort = true)
    private String mobile;

    private int sex;

    @FieldProp(name = "sexStr", showName = "性别", showStatus = 0, queryProp = "sex", sort = true)
    private String sexStr;

    private int consultSource;

    @FieldProp(name = "consultSourceStr", showName = "来源", showStatus = 0, queryProp = "consultSource", sort = true)
    private String consultSourceStr;

    private long cascadeId;

    @FieldProp(name = "cascadeIdStr", showName = "课程顾问", showStatus = 0)
    private String cascadeIdStr;

    private int consultStatus;

    @FieldProp(name = "consultStatusStr", showName = "跟进状态", showStatus = 0, queryProp = "consultStatus", sort = true)
    private String consultStatusStr;

    private int intensionLevel = 1;

    @FieldProp(name = "intensionLevelStr", showName = "意向级别", showStatus = 0, queryProp = "intensionLevel", sort = true)
    private String intensionLevelStr = "中";

//    private Date nextRemindTime;
//
//    @FieldProp(name = "nextRemindTimeStr", showName = "下次跟进时间", showStatus = 0, queryProp = "nextRemindTime", sort = true)
//    private String nextRemindTimeStr;

    private Date birthday;

    @FieldProp(name = "birthdayStr", showName = "生日", showStatus = 1, queryProp = "birthday", sort = true)
    private String birthdayStr;

    private Integer relatives;

    @FieldProp(name = "relativesStr", showName = "亲属关系", showStatus = 1, queryProp = "relatives", sort = true)
    private String relativesStr;

    @FieldProp(name = "parentName", showName = "家长姓名", showStatus = 1, queryProp = "parentName", sort = true)
    private String parentName;

    @FieldProp(name = "parentMobile", showName = "家长手机号", showStatus = 1, queryProp = "parentMobile", sort = true)
    private String parentMobile;

    @FieldProp(name = "school", showName = "公立学校", showStatus = 1, queryProp = "school", sort = true)
    private String school;

    @FieldProp(name = "degreeClass", showName = "年级", showStatus = 1, queryProp = "degreeClass", sort = true)
    private String degreeClass;

    @FieldProp(name = "address", showName = "详细地址", showStatus = 1, queryProp = "address", sort = true)
    private String address;

    @FieldProp(name = "qq", showName = "QQ", showStatus = 1, queryProp = "qq", sort = true)
    private String qq;

    @FieldProp(name = "mail", showName = "邮箱", showStatus = 1, queryProp = "mail", sort = true)
    private String mail;

    @FieldProp(name = "tagsStr", showName = "标签", showStatus = 1)
    private String tagsStr;
}

==> sal-display-2.45.0-20171102.162217-32-sources.jar: com/baijia/tianxiao/sal/display/dto/response/crm/DefaultClueField.java <==
package com.baijia.tianxiao.sal.display.dto.response.crm;

import com.baijia.tianxiao.sal.display.dto.annotation.FieldProp;
import lombok.Data;

import java.util.Date;

/**
 * 线索系统字段默认属性
 * Created by wangsixia on 2016/11/11.
 */
@Data
public class DefaultClueField{

    @FieldProp(name = "id", showName = "id", showStatus = 2)
    private Long id;

    @FieldProp(name = "name", showName = "姓名", showStatus = 0, queryProp = "name", lock = true, sort = true)
    private String name;

    private int sex;

    @FieldProp(name = "sexStr", showName = "性别", showStatus = 0, queryProp = "sex", lock = true,sort = true)
    private String sexStr;

    @FieldProp(name = "mobile", showName = "手机号", showStatus = 0, queryProp = "mobile", lock = true, sort = true)
    private String mobile;

    private int consultSource;

    @FieldProp(name = "consultSourceStr", showName = "来源", showStatus = 0, queryProp = "consultSource", sort = true)
    private String consultSourceStr;

    private long cascadeId;

    @FieldProp(name = "cascadeIdStr", showName = "课程顾问", showStatus = 0)
    private String cascadeIdStr;

    private int consultStatus;

    @FieldProp(name = "consultStatusStr", showName = "跟进状态", showStatus = 0, queryProp = "consultStatus", sort = true)
    private String consultStatusStr;

    private int intensionLevel = 1;

    @FieldProp(name = "intensionLevelStr", showName = "意向级别", showStatus = 0, queryProp = "intensionLevel", sort = true)
    private String intensionLevelStr = "中";

    private Date birthday;

    @FieldProp(name = "birthdayStr", showName = "生日", showStatus = 1, queryProp = "birthday", sort = true)
    private String birthdayStr;

    private Date createTime;

    @FieldProp(name = "createTimeStr", showName = "创建时间", showStatus = 1, queryProp = "createTime", sort = true)
    private String createTimeStr;

    private Date lastRemindTime;

    @FieldProp(name = "lastRemindTimeStr", showName = "最后操作时间", showStatus = 1, queryProp = "lastRemindTime", sort = true)
    private String lastRemindTimeStr;

    private Date lastFollowTime;

    @FieldProp(name = "lastFollowTimeStr", showName = "最后跟进时间", showStatus = 1, queryProp = "lastFollowTime", sort = true)
    private String lastFollowTimeStr;

    private Integer relatives;

    @FieldProp(name = "relativesStr", showName = "亲属关系", showStatus = 1, queryProp = "relatives", sort = true)
    private String relativesStr;

    @FieldProp(name = "parentName", showName = "家长姓名", showStatus = 1, queryProp = "parentName", sort = true)
    private String parentName;

    @FieldProp(name = "parentMobile", showName = "家长手机号", showStatus = 1, queryProp = "parentMobile", sort = true)
    private String parentMobile;

    @FieldProp(name = "school", showName = "公立学校", showStatus = 1, queryProp = "school", sort = true)
    private String school;

    @FieldProp(name = "degreeClass", showName = "年级", showStatus = 1, queryProp = "degreeClass", sort = true)
    private String degreeClass;

    @FieldProp(name = "address", showName = "详细地址", showStatus = 1, queryProp = "address", sort = true)
    private String address;

    @FieldProp(name = "qq", showName = "QQ", showStatus = 1, queryProp = "qq", sort = true)
    private String qq;

    @FieldProp(name = "mail", showName = "邮箱", showStatus = 1, queryProp = "mail", sort = true)
    private String mail;

    @FieldProp(name = "tagsStr", showName = "标签", showStatus = 1)
    private String tagsStr;
}
